@@ -1,9 +1,9 @@
 from __future__ import unicode_literals
+import json
 
 from django.core.exceptions import ValidationError
 from django.conf import settings
 from django.db import models, DatabaseError, transaction
-from django.utils import simplejson as json
 from django.utils.translation import ugettext_lazy as _
 from django.utils import six
 
@@ -66,10 +66,10 @@ class JSONField(six.with_metaclass(models.SubfieldBase, models.Field)):
         # (Protip: nothing does, at this stage).
         cursor = connection.cursor()
         try:
-            sid = transaction.savepoint()
+            sid = transaction.savepoint(using=connection.alias)
             cursor.execute('SELECT \'{}\'::json = \'{}\'::json;')
         except DatabaseError:
-            transaction.savepoint_rollback(sid)
+            transaction.savepoint_rollback(sid, using=connection.alias)
             return 'text'
         else:
             return 'json'
