@@ -1,5 +1,6 @@
+import json 
+
 from django import forms
-from django.utils import simplejson as json
 from django.conf import settings
 
 from .utils import default
